## Aliases

The following lists all implemented metric averaging methods, by alias. These can be used when composing metrics using [metric syntax strings](http://ioverho.github.io/prob_conf_mat/How%20To%20Guides/metric_syntax.html).

@@averaging_table@@

## Abstract Base Class

::: prob_conf_mat.metrics.abc.Averaging
    options:
        heading_level: 3
        members:
            - "dependencies"
            - "sklearn_equivalent"
            - "aliases"
            - "compute_average"

## Metric Instances

@@averaging_methods_list@@
